package envoy.event;

import envoy.data.User;

/**
 * Signifies the modification of a contact list.<br>
 * <br>
 * Project: <strong>envoy-common</strong><br>
 * File: <strong>ContactOperationEvent.java</strong><br>
 * Created: <strong>05.02.2020</strong><br>
 *
 * @author Maximilian K&auml;fer
 * @since Envoy Common v0.2-alpha
 */
public class ContactOperationEvent implements Event<User> {

	/**
	 * Specifies the operation performed on a contact list.<br>
	 * <br>
	 * Project: <strong>envoy-common</strong><br>
	 * File: <strong>ContactOperationEvent.java</strong><br>
	 * Created: <strong>05.02.2020</strong><br>
	 *
	 * @author Maximilian K&auml;fer
	 * @since Envoy Common v0.2-alpha
	 */
	public enum Operation {

		/**
		 * Adds a user to the contact list.
		 */
		ADD,

		/**
		 * Removes a user from the contact list.
		 */
		REMOVE;
	}

	private final User		contact;
	private final Operation	operationType;

	private static final long serialVersionUID = -1166652868189511553L;

	/**
	 * Initializes a {@link ContactOperationEvent}.
	 *
	 * @param contact       the user on which the operation is performed
	 * @param operationType the type of operation to perform
	 * @since Envoy Common v0.2-alpha
	 */
	public ContactOperationEvent(User contact, Operation operationType) {
		this.contact		= contact;
		this.operationType	= operationType;
	}

	/**
	 * @return the user to perform an operation on
	 * @since Envoy Common v0.2-alpha
	 */
	@Override
	public User get() { return contact; }

	/**
	 * @return the type of operation to perform
	 * @since Envoy Common v0.2-alpha
	 */
	public Operation getOperationType() { return operationType; }
}
