package envoy.event;

/**
 * Signifies to the client that the handshake failed for the attached
 * reason.<br>
 * <br>
 * Project: <strong>envoy-common</strong><br>
 * File: <strong>HandshakeRejectionEvent.java</strong><br>
 * Created: <strong>28 Jan 2020</strong><br>
 *
 * @author Kai S. K. Engelbart
 * @since Envoy Common v0.3-alpha
 */
public class HandshakeRejectionEvent implements Event<String> {

	private final String reason;

	private static final long serialVersionUID = -8723270093452609197L;

	/**
	 * Creates an instance of {@link HandshakeRejectionEvent} with an empty reason.
	 *
	 * @since Envoy Common v0.3-alpha
	 */
	public HandshakeRejectionEvent() { this(""); }

	/**
	 * Creates an instance of {@link HandshakeRejectionEvent}.
	 *
	 * @param reason the reason why the handshake was rejected
	 * @since Envoy Common v0.3-alpha
	 */
	public HandshakeRejectionEvent(String reason) { this.reason = reason; }

	/**
	 * @return the reason why the handshake was rejected
	 * @since Envoy Common v0.3-alpha
	 */
	@Override
	public String get() { return reason; }
}
